@@ -172,13 +172,20 @@ def entry(obj: Changelog, bullets, paragraphs, section_name, version_name):
 
 
 @cli.command(short_help='Release versions.')
-@click.option('-M', '--major', 'rel_seg', flag_value=0, default=None, help='Increment major version number.')
-@click.option('-m', '--minor', 'rel_seg', flag_value=1, help='Increment minor version number.')
-@click.option('-p', '--patch', 'rel_seg', flag_value=2, help='Increment patch number.')
-@click.option('-a', '--alpha', 'pre_seg', flag_value='a', default=None, help='Increment alpha version number.')
-@click.option('-b', '--beta', 'pre_seg', flag_value='b', help='Increment beta version number.')
-@click.option('-r', '--rc', 'pre_seg', flag_value='rc', help='Increment release candidate version number.')
-@click.option('-f', '--full', 'pre_seg', flag_value='', help='Clear the prerelease value creating a full release.')
+@click.option('-M', '--major', 'rel_seg', flag_value=0, type=int, default=None,
+              help='Increment major version number.')
+@click.option('-m', '--minor', 'rel_seg', flag_value=1, type=int,
+              help='Increment minor version number.')
+@click.option('-p', '--patch', 'rel_seg', flag_value=2, type=int,
+              help='Increment patch number.')
+@click.option('-a', '--alpha', 'pre_seg', flag_value='a', type=str, default=None,
+              help='Increment alpha version number.')
+@click.option('-b', '--beta', 'pre_seg', flag_value='b', type=str,
+              help='Increment beta version number.')
+@click.option('-r', '--rc', 'pre_seg', flag_value='rc', type=str,
+              help='Increment release candidate version number.')
+@click.option('-f', '--full', 'pre_seg', flag_value='',
+              help='Clear the prerelease value creating a full release.')
 @click.option('-c', '--commit', is_flag=True,
               help='Create a git commit tagged with the new version number. '
                    'If there are no changes to commit, the current commit will be tagged instead.')
@@ -255,12 +262,16 @@ def release(obj: Changelog, version_name, rel_seg, pre_seg, commit):
         click.confirm(' '.join(message), abort=True)
 
         if tracked > 0:
-            commit = repo.index.commit(f'Version {cur_version.name}\n\n{cur_version.body()}')
+            commit = repo.index.commit(f'Release {cur_version.name}\n\n{cur_version.body()}')
             click.echo(f"Created commit {click.style(repo.head.commit.hexsha[0:7], fg='green')}")
         else:
             commit = repo.head.commit
 
-        repo_tag = repo.create_tag(cur_version.name, ref=commit, message=cur_version.body(False))
+        short_version, *_ = yaclog.version.extract_version(cur_version.name)
+        if not short_version:
+            short_version = cur_version.name.replace(' ', '-')
+
+        repo_tag = repo.create_tag(short_version, ref=commit, message=cur_version.body(False))
         click.echo(f"Created tag {click.style(repo_tag.name, fg='green')}.")
 
 
